@@ -6,16 +6,12 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( sec_to_time check_mapping_stdout write_json read_json uni_capture uni_system HIDE_CURSOR SHOW_CURSOR );
+our @EXPORT_OK = qw( sec_to_time write_json read_json uni_capture uni_system HIDE_CURSOR SHOW_CURSOR );
 
-use Encode             qw( encode FB_CROAK LEAVE_SRC );
 use Fcntl              qw( LOCK_EX LOCK_SH SEEK_END );
-use Unicode::Normalize qw( NFC );
 
-use Encode::Locale         qw();
 use IPC::System::Simple    qw( capture system );
 use JSON                   qw();
-#use Text::Unidecode       qw( unidecode ); # require-d
 
 use if $^O eq 'MSWin32', 'Win32::ShellQuote';
 
@@ -25,36 +21,6 @@ use constant {
 };
 
 
-sub check_mapping_stdout {
-    my ( $opt, $string ) = @_;
-    return $string if $Encode::Locale::ENCODING_CONSOLE_OUT =~ /^UTF-/i;
-    return $string if eval { encode( 'console_out', $string, FB_CROAK | LEAVE_SRC ) };
-    my $rc = eval {
-        require Text::Unidecode;
-        Text::Unidecode->import();
-        1;
-    };
-    if ( $rc ) {
-        my @words;
-        for my $word ( split / /, $string ) {
-            my $encoded_word;
-            if ( eval { $encoded_word = encode( 'console_out', $word, FB_CROAK | LEAVE_SRC ) } ) {
-                push @words, $encoded_word;
-            }
-            else {
-                my $unidecoded_word = Text::Unidecode::unidecode( $word );
-                push @words, $unidecoded_word;
-            }
-        }
-        return join ' ', @words;
-    }
-    binmode STDOUT, ':pop';
-    my $encoded_lax = encode( 'console_out', NFC $string, sub { '*' } );
-    binmode STDOUT, ':encoding(console_out)';
-    return $encoded_lax;
-}
-
-
 sub uni_capture {
     my ( @cmd ) = @_;
     if ( wantarray ) {
